# rc3.world Best Practices

## Best Practices

After last year's rc3 and the following divocs the following crystallised as best
practices for map building (apart from the technical requirements of workadventure
itself). Please keep them in mind while designing your assemblies.

## Logic
- Place collisions only in places where they make sense — so please avoid things
  like invisible walls
- Make exists (especially those back to your main map) obviously visible; don't
  build one-way portals to maps with no way back
- "Riddle"-maps should have an easily visible exit directly next to the start;
  ideally it should be impossible to accidentally "fall" into the map
- please avoid endless exit-loops, or clearly mark them as portals — exits should
  not lead lead to entrypoints of the same map
- place active elements far enough apart that it's easy to walk between them,
  especially if your map connects several other maps

## Accessability
- avoid animations or design them to be unobtrusive
- take care to have sufficient contrast (especially between e.g. walls/floor)
- mark areas playing sounds/music or opening jitsis (e.g. with a sign); don't
  place them directly on the entrypoint where people might run into them by
  mistake
- place jitsis so that people can walk around them
- include silent areas (a layer with property `silent` set to `true`)
- mark thin passages as silent areas, or widen them so people can walk past each
  other without initiating a chat bubble
- please think of direction when adding portals between maps — walking straight
  through an exit and then continuing on should not immideately lead to another
  exit. If in doubt, just include a few tiles distance between the two.
- if applicable, include content warnings 
- warnings in front of long labyrinths or epileptic animations should be signs
  next to the exit that leads to the corresponding map, or next to an early exit
  directly at the map's start

## Reachability without the world
Not everyone can or wants to interact with the event through the world. So no
matter how beautiful your carefully designed worlds may be — please think about
how one might reach your assembly without walking through the world. Add links
to your jitsi-rooms to your assembly's page in the hub (especially if workshops
take place in them!), don't publish your schedule exlusively as a sign on your
map, etc.
